
.. _`Appendix`:

Appendix
========

This section contains information that is referenced from other sections,
and that does not really need to be read in sequence.


.. _`References`:

References
----------

.. glossary::

   Python Glossary
      * `Python 3 Glossary <https://docs.python.org/3/glossary.html>`_

   Default Case Folding in The Unicode Standard
     `"Default Case Folding" in The Unicode Standard Version 15.0 <https://www.unicode.org/versions/Unicode15.0.0/ch03.pdf>`_
